pub struct CourseModuleSuotarConfiguration {Show 14 fields
pub id: Uuid,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub deleted_at: Option<DateTime<Utc>>,
pub course_module_id: Uuid,
pub open_university_product_id: Option<String>,
pub grade_scale_id: Option<String>,
pub paused_at: Option<DateTime<Utc>>,
pub paused_by_user_id: Option<Uuid>,
pub pause_reason: Option<String>,
pub config_checked_at: Option<DateTime<Utc>>,
pub course_code_resolves: Option<bool>,
pub product_token_found: Option<bool>,
pub config_check_message: Option<String>,
}Fields
id: Uuidcreated_at: DateTime<Utc>updated_at: DateTime<Utc>deleted_at: Option<DateTime<Utc>>course_module_id: Uuidopen_university_product_id: Option<String>grade_scale_id: Option<String>None means derive the grade scale from the completion.
paused_at: Option<DateTime<Utc>>paused_by_user_id: Option<Uuid>pause_reason: Option<String>config_checked_at: Option<DateTime<Utc>>course_code_resolves: Option<bool>None means never checked, which is not the same as a failed check.
product_token_found: Option<bool>config_check_message: Option<String>Trait Implementations
Sourceimpl Clone for CourseModuleSuotarConfiguration
impl Clone for CourseModuleSuotarConfiguration
Sourcefn clone(&self) -> CourseModuleSuotarConfiguration
fn clone(&self) -> CourseModuleSuotarConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CourseModuleSuotarConfiguration
impl ComposeSchema for CourseModuleSuotarConfiguration
Sourceimpl<'de> Deserialize<'de> for CourseModuleSuotarConfiguration
impl<'de> Deserialize<'de> for CourseModuleSuotarConfiguration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CourseModuleSuotarConfiguration
impl PartialEq for CourseModuleSuotarConfiguration
Sourcefn eq(&self, other: &CourseModuleSuotarConfiguration) -> bool
fn eq(&self, other: &CourseModuleSuotarConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CourseModuleSuotarConfiguration
impl ToSchema for CourseModuleSuotarConfiguration
impl StructuralPartialEq for CourseModuleSuotarConfiguration