pub async fn count_modules_failing_config_check(
conn: &mut PgConnection,
) -> ModelResult<i64>Expand description
Enabled modules the last check found broken. A module nothing has checked yet is not counted: unknown is not a failure.
pub async fn count_modules_failing_config_check(
conn: &mut PgConnection,
) -> ModelResult<i64>Enabled modules the last check found broken. A module nothing has checked yet is not counted: unknown is not a failure.